@@ -2,12 +2,9 @@
 #define TRAILGPXVIEW_H
 
 #include <QWidget>
-#include <QtLocation/QGeoMapObject>
-#include <QtLocation/QGraphicsGeoMap>
-
-#include <QGraphicsScene>
-#include <QGraphicsView>
+#include <QtLocation/QGeoMapPolylineObject>
 
+class MapWidget;
 class QWebView;
 class QVBoxLayout;
 class TrailInterface;
@@ -18,7 +15,7 @@ class TrailGPXView : public QWidget
 public:
     explicit TrailGPXView(TrailInterface*, QWidget *parent = 0);
 
-    void addMapObject(QtMobility::QGeoMapObject*, bool fit);
+    void addMapObject(QtMobility::QGeoMapPolylineObject*, bool fit);
     void clearMapObjects();
 
 signals:
@@ -26,10 +23,7 @@ signals:
 public slots:
 
 private:
-    QtMobility::QGraphicsGeoMap *m_mapWidget;
-
-    QGraphicsView *m_qgv;
-    QGraphicsScene *m_scene;
+    MapWidget *m_map;
 
     QVBoxLayout *m_layout;
 };
