@@ -50,30 +50,14 @@ TrailGPXRecorder::TrailGPXRecorder(TrailInterface *interface, QWidget *parent) :
     m_btnLayout->addWidget(m_switch);
     m_layout->addLayout(m_btnLayout);
     
+    m_mapWidget = new MapWidget(interface, this);
+
     m_gpxList = new QTableView(this);
     m_gpxList->horizontalHeader()->setVisible(true);
     m_gpxList->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
 
-    m_scene = new QGraphicsScene(this);
-    m_scene->setSceneRect(0,0,800,800);
-
-    m_qgv = new QGraphicsView(m_scene, this);
-    m_qgv->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    m_qgv->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    m_qgv->setVisible(true);
-    m_qgv->setInteractive(true);
-    m_mapWidget = new MapWidget(interface->mappingManager());
-    m_mapWidget->setCenter(QtMobility::QGeoCoordinate(-27.0, 152.0));
-    m_mapWidget->setZoomLevel(13);
-    m_mapWidget->setMapType(QtMobility::QGraphicsGeoMap::TerrainMap);
-    m_mapWidget->setPreferredSize(800,800);
-
-    m_scene->addItem(m_mapWidget);
-    m_qgv->setSceneRect(0,0,800,800);
-    m_qgv->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-
     m_mapStack = new QStackedWidget(this);
-    m_mapStack->addWidget(m_qgv);
+    m_mapStack->addWidget(m_mapWidget);
     m_mapStack->addWidget(m_gpxList);
 
     m_layout->addWidget(m_mapStack);
@@ -108,9 +92,8 @@ TrailGPXRecorder::TrailGPXRecorder(TrailInterface *interface, QWidget *parent) :
     m_currentCircle->setPen(QPen(Qt::red, 3));
     m_currentCircle->setBrush(QBrush(QColor(128,0,0,128)));
 
-    addMapObject(m_currentCircle, false);
-    addMapObject(m_poly, false);
-
+    m_mapWidget->addMapObject(m_currentCircle);
+    m_mapWidget->addMapObject(m_poly);
     m_mapWidget->setCenter(m_currentCircle->center());
 }
 
@@ -159,19 +142,27 @@ void TrailGPXRecorder::slotStop()
 
 void TrailGPXRecorder::slotSwitchView()
 {
-    if (m_mapStack->currentWidget() == m_qgv) {
+    if (m_mapStack->currentWidget() == m_mapWidget) {
         m_mapStack->setCurrentWidget(m_gpxList);
     } else {
-        m_mapStack->setCurrentWidget(m_qgv);
+        m_mapStack->setCurrentWidget(m_mapWidget);
     }
 }
 
 void TrailGPXRecorder::positionUpdated(const QGeoPositionInfo& pos)
 {
-    m_curPos->setText(QString("<b>Current Position: </b>%1:%2").arg(pos.coordinate().latitude()).arg(pos.coordinate().longitude()));
     m_curLatitude->setText(QString("<b>Latitude: </b>%1").arg(pos.coordinate().latitude()));
     m_curLongitude->setText(QString("<b>Longitude: </b>%1").arg(pos.coordinate().longitude()));
 
+    if (width() > height()) {
+        //Landscape
+        m_curPos->setText(QString("<b>Current Position: </b>%1:%2").arg(pos.coordinate().latitude()).arg(pos.coordinate().longitude()));
+    }
+    else {
+        //Portrait
+        m_curPos->setText(QString("<b>Current Position: </b>"));
+    }
+
     m_currentCircle->setCenter(pos.coordinate());
 
     m_path.clear();
@@ -190,6 +181,10 @@ void TrailGPXRecorder::resizeEvent(QResizeEvent *event)
         //Landscape
         m_curLongitude->hide();
         m_curLatitude->hide();
+
+        if (m_model) {
+            m_curPos->setText(QString("<b>Current Position: </b>%1:%2").arg(m_model->currentPosition().coordinate().latitude()).arg(m_model->currentPosition().coordinate().longitude()));
+        }
     } else {
         //Portrait
         m_curLongitude->show();
@@ -198,15 +193,6 @@ void TrailGPXRecorder::resizeEvent(QResizeEvent *event)
     }
 }
 
-void TrailGPXRecorder::addMapObject(QtMobility::QGeoMapObject *obj, bool fit)
-{
-    m_mapWidget->addMapObject(obj);
-
-    if (fit) {
-        m_mapWidget->fitInViewport(obj->boundingBox());
-    }
-}
-
 void TrailGPXRecorder::clearMapObjects()
 {
     m_mapWidget->clearMapObjects();
